@@ -24,4 +24,4 @@ plt.plot(lam*1000,qsca)
 plt.title("BK7 glass spheres 4 micron diameter")
 plt.xlabel("Wavelength (nm)")
 plt.ylabel("Scattering Efficiency (-)")
-plt.show()
+# plt.show()
