@@ -27,4 +27,4 @@ plt.plot(lam*1000, qsca)
 plt.title(r"Water Droplets (1 µm diameter)")
 plt.xlabel("Wavelength (nm)")
 plt.ylabel(r"Scattering Cross Section (µm$^2$)")
-plt.show()
+# plt.show()
