@@ -61,4 +61,4 @@ plt.ylabel(r"Cross Section (µm$^2$)")
 plt.text(700, 0.01, "absorption", color='blue')
 plt.text(750, 0.1, "scattering", color='red')
 plt.savefig("04_plot.png")
-plt.show()
+# plt.show()
